@@ -365,6 +365,8 @@ struct ParameterEnumerationValues {
             values = nullptr;
         }
     }
+
+    DISTRHO_DECLARE_NON_COPY_STRUCT(ParameterEnumerationValues)
 };
 
 /**
@@ -384,6 +386,13 @@ struct Parameter {
     */
     String name;
 
+   /**
+      The short name of this parameter.@n
+      Used when displaying the parameter name in a very limited space.
+      @note This value is optional, the full name is used when the short one is missing.
+    */
+    String shortName;
+
    /**
       The symbol of this parameter.@n
       A parameter symbol is a short restricted name used as a machine and human readable identifier.@n
@@ -399,6 +408,12 @@ struct Parameter {
     */
     String unit;
 
+   /**
+      An extensive description/comment about the parameter.
+      @note This value is optional and only used for LV2.
+    */
+    String description;
+
    /**
       Ranges of this parameter.@n
       The ranges describe the default, minimum and maximum values.
@@ -430,6 +445,7 @@ struct Parameter {
     Parameter() noexcept
         : hints(0x0),
           name(),
+          shortName(),
           symbol(),
           unit(),
           ranges(),
@@ -443,6 +459,7 @@ struct Parameter {
     Parameter(uint32_t h, const char* n, const char* s, const char* u, float def, float min, float max) noexcept
         : hints(h),
           name(n),
+          shortName(),
           symbol(s),
           unit(u),
           ranges(def, min, max),
@@ -462,11 +479,12 @@ struct Parameter {
         case kParameterDesignationNull:
             break;
         case kParameterDesignationBypass:
-            hints  = kParameterIsAutomable|kParameterIsBoolean|kParameterIsInteger;
-            name   = "Bypass";
-            symbol = "dpf_bypass";
-            unit   = "";
-            midiCC = 0;
+            hints      = kParameterIsAutomable|kParameterIsBoolean|kParameterIsInteger;
+            name       = "Bypass";
+            shortName  = "Bypass";
+            symbol     = "dpf_bypass";
+            unit       = "";
+            midiCC     = 0;
             ranges.def = 0.0f;
             ranges.min = 0.0f;
             ranges.max = 1.0f;
