@@ -166,6 +166,44 @@ public:
 
     // -------------------------------------------------------------------
 
+    bool getPortControlValue(uint32_t index, float& value) const
+    {
+        if (const float* control = fPortControls[index])
+        {
+            switch (fPlugin.getParameterDesignation(index))
+            {
+            default:
+                value = *control;
+                break;
+            case kParameterDesignationBypass:
+                value = 1.0f - *control;
+                break;
+            }
+
+            return true;
+        }
+
+        return false;
+    }
+
+    void setPortControlValue(uint32_t index, float value)
+    {
+        if (float* control = fPortControls[index])
+        {
+            switch (fPlugin.getParameterDesignation(index))
+            {
+            default:
+                *control = value;
+                break;
+            case kParameterDesignationBypass:
+                *control = 1.0f - value;
+                break;
+            }
+        }
+    }
+
+    // -------------------------------------------------------------------
+
     void lv2_activate()
     {
 #if DISTRHO_PLUGIN_WANT_TIMEPOS
@@ -514,18 +552,13 @@ public:
 
         for (uint32_t i=0, count=fPlugin.getParameterCount(); i < count; ++i)
         {
-            if (fPortControls[i] == nullptr)
+            if (!getPortControlValue(i, curValue))
                 continue;
 
-            curValue = *fPortControls[i];
-
             if (fPlugin.isParameterInput(i) && d_isNotEqual(fLastControlValues[i], curValue))
             {
                 fLastControlValues[i] = curValue;
 
-                if (fPlugin.getParameterDesignation(i) == kParameterDesignationBypass)
-                    curValue = 1.0f - curValue;
-
                 fPlugin.setParameterValue(i, curValue);
             }
         }
@@ -757,8 +790,7 @@ public:
 
             fLastControlValues[i] = fPlugin.getParameterValue(i);
 
-            if (fPortControls[i] != nullptr)
-                *fPortControls[i] = fLastControlValues[i];
+            setPortControlValue(i, fLastControlValues[i]);
         }
 
 # if DISTRHO_PLUGIN_WANT_FULL_STATE
@@ -846,6 +878,11 @@ public:
 
         return LV2_WORKER_SUCCESS;
     }
+
+    LV2_Worker_Status lv2_work_response(uint32_t, const void*)
+    {
+        return LV2_WORKER_SUCCESS;
+    }
 #endif
 
     // -------------------------------------------------------------------
@@ -1042,8 +1079,7 @@ private:
             {
                 curValue = fLastControlValues[i] = fPlugin.getParameterValue(i);
 
-                if (fPortControls[i] != nullptr)
-                    *fPortControls[i] = curValue;
+                setPortControlValue(i, curValue);
             }
             else if ((fPlugin.getParameterHints(i) & kParameterIsTrigger) == kParameterIsTrigger)
             {
@@ -1243,6 +1279,11 @@ LV2_Worker_Status lv2_work(LV2_Handle instance, LV2_Worker_Respond_Function, LV2
 {
     return instancePtr->lv2_work(data);
 }
+
+LV2_Worker_Status lv2_work_response(LV2_Handle instance, uint32_t size, const void* body)
+{
+    return instancePtr->lv2_work_response(size, body);
+}
 #endif
 
 // -----------------------------------------------------------------------
@@ -1272,7 +1313,7 @@ static const void* lv2_extension_data(const char* uri)
 
 #if DISTRHO_PLUGIN_WANT_STATE
     static const LV2_State_Interface state = { lv2_save, lv2_restore };
-    static const LV2_Worker_Interface worker = { lv2_work, nullptr, nullptr };
+    static const LV2_Worker_Interface worker = { lv2_work, lv2_work_response, nullptr };
 
     if (std::strcmp(uri, LV2_STATE__interface) == 0)
         return &state;
