@@ -2,14 +2,12 @@
 
 set -e
 
-MODGUIS=("Kars" "MVerb" "MVerb" "Nekobi" "PingPongPan")
-
 # --------------------------------------------------------------------------------------------------------------------------------
 # extract debs and pack them
 
 function compressFolderAsZip() {
 rm -f "$1.zip"
-zip -X -r "$1" "$1"
+zip -X -r "$1.zip" "$1"
 rm -r "$1"
 }
 
@@ -20,40 +18,30 @@ echo Missing argument
 exit
 fi
 
-sed -i -e "s|-MD -MP|-D_MD_MP_WORKAROUND|" */*.mk dpf/dgl/*.mk
+sed -i -e "s|-MD -MP|-D_MD_MP_WORKAROUND|" */*.mk
 
 # --------------------------------------------------------------------------------------------------------------------------------
 
-cd bin
-
-mkdir -p tmp
-rm -rf tmp/*
-
 NAME="$1"
 
-export CFLAGS="-mmacosx-version-min=10.5 -DMAC_OS_X_VERSION_MAX_ALLOWED=1060 -arch i386 -arch x86_64"
-export CXXFLAGS=$CFLAGS
-export LDFLAGS=$CFLAGS
+rm -rf "$NAME-macOS"
+
+export CFLAGS="-mmacosx-version-min=10.5 -DMAC_OS_X_VERSION_MAX_ALLOWED=1060 -arch i386 -arch x86_64 -mfpmath=sse"
+export CXXFLAGS="$CFLAGS"
+export LDFLAGS="$CFLAGS"
 export MACOS="true"
 export MACOS_OLD="true"
 
-make -C .. clean
-make HAVE_JACK=false HAVE_LIBLO=false HAVE_PROJM=false -C .. -j 4
-rm -rf *ladspa* *dssi*
+make clean
+make HAVE_JACK=false HAVE_LIBLO=false HAVE_PROJM=false -j 2
+rm -rf bin/*ladspa* bin/*dssi*
 mkdir -p "$NAME-macOS"
-mv *.lv2 *.vst "$NAME-macOS"
-for MODGUI in ${MODGUIS[@]}; do
-  cp -r ../modguis/$MODGUI.modgui/modgui "$NAME-macOS"/$MODGUI.lv2/
-  cp ../modguis/$MODGUI.modgui/manifest.ttl "$NAME-macOS"/$MODGUI.lv2/modgui.ttl
-done
-cp "../utils/README-MacOS.txt" "$NAME-macOS/README.txt"
+mv bin/*.lv2 bin/*.vst "$NAME-macOS"
+cp utils/README-MacOS.txt "$NAME-macOS/README.txt"
 compressFolderAsZip "$NAME-macOS"
-rm -rf tmp/*
 
-make -C .. clean
-
-cd ..
+make clean
 
 # --------------------------------------------------------------------------------------------------------------------------------
 
-sed -i -e "s|-D_MD_MP_WORKAROUND|-MD -MP|" */*.mk dpf/dgl/*.mk
+sed -i -e "s|-D_MD_MP_WORKAROUND|-MD -MP|" */*.mk
